// Thanks Nodemachine
var sys = require('sys');

module.exports = [
  {
    name: "v3b13 false",
    appConfig: { ping: false },
    method: "GET",
    path: "/",
    headers: {},
    checkStatus: 503,
    checkStack: ["v3b13"],
  },
  {
    name: "v3b13b false",
    appConfig: { serviceAvailable: false },
    method: "GET",
    path: "/",
    headers: {},
    checkStatus: 503,
    checkStack: ["v3b13", "v3b13b"],
  },
  {
    name: "v3b13b true",
    appConfig: { knownMethodsSync: ["HEAD", "POST"] },
    method: "GET",
    path: "/",
    headers: {},
    checkStatus: 501,
    checkStack: ["v3b13", "v3b13b", "v3b12"],
  },
  {
    name: "v3b12 false",
    appConfig: { knownMethodsSync: ["HEAD", "POST"] },
    method: "GET",
    path: "/",
    headers: {},
    checkStatus: 501,
    checkStack: ["v3b13", "v3b13b", "v3b12"],
  },
  {
    name: "v3b12 true",
    appConfig: { knownMethodsSync: ["GET", "HEAD", "POST"], uriTooLong: true },
    method: "GET",
    path: "/",
    headers: {},
    checkStatus: 414,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11"],
  },
  {
    name: "v3b11 true",
    appConfig: { uriTooLong: true },
    method: "GET",
    path: "/",
    headers: {},
    checkStatus: 414,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11"],
  },
  {
    name: "v3b11 false",
    appConfig: { allowedMethodsSync: ["HEAD", "POST"] },
    method: "GET",
    path: "/",
    headers: {},
    checkStatus: 405,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10"],
  },
  {
    name: "v3b10 false",
    appConfig: { allowedMethodsSync: ["HEAD", "POST"] },
    method: "GET",
    path: "/",
    headers: {},
    checkStatus: 405,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10"],
  },
  {
    name: "v3b10 true",
    appConfig: { allowedMethodsSync: ["GET", "HEAD", "POST"], malformedRequest: true },
    method: "GET",
    path: "/",
    headers: {},
    checkStatus: 400,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9"],
  },
  {
    name: "v3b9 true",
    appConfig: { malformedRequest: true },
    method: "GET",
    path: "/",
    headers: {},
    checkStatus: 400,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9"],
  },
  {
    name: "v3b9 false",
    appConfig: { isAuthorized: false, getAuthenticationHeader: "Basic realm=\"Test\"" },
    method: "GET",
    path: "/",
    headers: {},
    checkStatus: 401,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8"],
    checkHeaders: function (headers) { return(headers["www-authenticate"] == "Basic realm=\"Test\""); },
  },
  {
    name: "v3b8 false",
    appConfig: { isAuthorized: false, getAuthenticationHeader: "Basic realm=\"Test\"" },
    method: "GET",
    path: "/",
    headers: {},
    checkStatus: 401,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8"],
    checkHeaders: function (headers) { return(headers["www-authenticate"] == "Basic realm=\"Test\""); },
  },
  {
    name: "v3b8 true",
    appConfig: { forbidden: true },
    method: "GET",
    path: "/",
    headers: {},
    checkStatus: 403,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7"],
  },
  {
    name: "v3b7 true",
    appConfig: { forbidden: true },
    method: "GET",
    path: "/",
    headers: {},
    checkStatus: 403,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7"],
  },
  {
    name: "v3b7 false",
    appConfig: { validContentHeaders: false },
    method: "GET",
    path: "/",
    headers: {},
    checkStatus: 501,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6"],
  },
  {
    name: "v3b6 true",
    appConfig: { validContentHeaders: false },
    method: "GET",
    path: "/",
    headers: {},
    checkStatus: 501,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6"],
  },
  {
    name: "v3b6 false",
    appConfig: { allowedMethodsSync: ["PUT"], knownContentType: false }, //contentTypesAcceptedSync: {"text/plain": "textPlain"} },
    method: "PUT",
    path: "/",
    headers: { "Content-type": "application/javascript" },
    checkStatus: 415,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5"],
  },
  {
    name: "v3b5 false",
    appConfig: { allowedMethodsSync: ["PUT"], knownContentType: false }, //contentTypesAcceptedSync: {"text/plain": "textPlain"} },
    method: "PUT",
    path: "/",
    headers: { "Content-type": "application/javascript" },
    checkStatus: 415,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5"],
  },
  {
    name: "v3b5 true",
    appConfig: { allowedMethodsSync: ["PUT"], contentTypesAcceptedSync: ["application/octet-stream", "text/plain"], validEntityLength: false },
    method: "PUT",
    path: "/",
    headers: { "Content-type": "text/plain" },
    checkStatus: 413,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4"],
  },
  {
    name: "v3b5 true (*/*)",
    appConfig: { allowedMethodsSync: ["PUT"], contentTypesAcceptedSync: ["application/octet-stream", "*/*"], validEntityLength: false },
    method: "PUT",
    path: "/",
    headers: { "Content-type": "text/plain" },
    checkStatus: 413,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4"],
  },
  {
    name: "v3b5 true ([])",
    appConfig: { allowedMethodsSync: ["PUT"], contentTypesAcceptedSync: [], validEntityLength: false },
    method: "PUT",
    path: "/",
    headers: { "Content-type": "application/octet-stream" },
    checkStatus: 413,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4"],
  },
  {
    name: "v3b5 true (no content-type)",
    appConfig: { allowedMethodsSync: ["PUT", "GET"], contentTypesAcceptedSync: ["application/octet-stream", "text/plain"], validEntityLength: false },
    method: "PUT",
    path: "/",
    headers: {},
    checkStatus: 413,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4"],
  },
  {
    name: "v3b4 false",
    appConfig: { validEntityLength: false },
    method: "GET",
    path: "/",
    headers: {},
    checkStatus: 413,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4"],
  },
  {
    name: "v3b4 true",
    appConfig: { validEntityLength: true, allowedMethodsSync: ["OPTIONS", "GET"] },
    method: "OPTIONS",
    path: "/",
    headers: {},
    checkStatus: 200,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3"],
  },
  {
    name: "v3b3 true",
    appConfig: { allowedMethodsSync: ["OPTIONS", "GET"] },
    method: "OPTIONS",
    path: "/",
    headers: {},
    checkStatus: 200,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3"],
  },
  {
    name: "v3c4 false",
    appConfig: { contentTypesProvidedSync: {"text/plain":'toText', "text/html":'toHtml'} },
    method: "GET",
    path: "/",
    headers: { "Accept": "application/javascript" },
    checkStatus: 406,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3c4"],
  },
  {
    name: "v3c4 true (*/*)",
    appConfig: { contentTypesProvidedSync: {"text/plain":'toText', "text/html":'toHtml'}, languageAvailable: false }, // ["de"]
    method: "GET",
    path: "/",
    headers: { "Accept": "*/*", "Accept-language": "en" },
    checkStatus: 406,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3c4", "v3d4", "v3d5"],
  },
  {
    name: "v3c4 true ([])",
    appConfig: { contentTypesProvidedSync: {"text/html":'toHtml'}, languageAvailable: false }, // ["de"]
    method: "GET",
    path: "/",
    headers: { "Accept": "text/html", "Accept-language": "en" },
    checkStatus: 406,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3c4", "v3d4", "v3d5"],
  },
  {
    name: "v3d5 false",
    appConfig: { languageAvailable: false }, //["de", "fr"] },
    method: "GET",
    path: "/",
    headers: { "Accept-language": "en" },
    checkStatus: 406,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3d5"],
  },
  {
    name: "v3d5 true",
    appConfig: { charsetsProvidedSync: {"iso-8859-5":"make_iso" } }, //["de", "fr"]
    method: "GET",
    path: "/",
    headers: { "Accept-language": "fr", "Accept-charset": "utf-8" },
    checkStatus: 406,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3d5", "v3e5", "v3e6"],
  },
  {
    name: "v3d5 true (*)",
    appConfig: { charsetsProvidedSync: {"iso-8859-5":"make_iso" } }, //["de", "fr"]
    method: "GET",
    path: "/",
    headers: { "Accept-language": "*", "Accept-charset": "utf-8" },
    checkStatus: 406,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3d5", "v3e5", "v3e6"],
  },
  // {
  //   name: "v3d5 true ([])",
  //   appConfig: { languageAvailable: [], charsetsProvidedSync: {"iso-8859-5":"make_iso"} },
  //   method: "GET",
  //   path: "/",
  //   headers: { "Accept-language": "en", "Accept-charset": "utf-8" },
  //   checkStatus: 406,
  //   checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3d5", "v3e5", "v3e6"],
  // },
  {
    name: "v3e6 false",
    appConfig: { charsetsProvidedSync: {"iso-8859-5":"make_iso", "unicode-1-1":"make_uni"} },
    method: "GET",
    path: "/",
    headers: { "Accept-charset": "utf-8" },
    checkStatus: 406,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3e6"],
  },
  {
    name: "v3e6 true",
    appConfig: { charsetsProvidedSync: {"iso-8859-5":"make_iso", "unicode-1-1":"make_uni"}, encodingsProvidedSync: {"chunked":function(body){return body;}} },
    method: "GET",
    path: "/",
    headers: { "Accept-charset": "unicode-1-1", "Accept-encoding": "deflate" },
    checkStatus: 406,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3e6", "v3f6", "v3f7"],
  },
  {
    name: "v3e6 true (*)",
    appConfig: { charsetsProvidedSync: {"iso-8859-5":"make_iso", "unicode-1-1":"make_uni"}, encodingsProvidedSync: {"chunked":function(body){return body;}} },
    method: "GET",
    path: "/",
    headers: { "Accept-charset": "*", "Accept-encoding": "deflate" },
    checkStatus: 406,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3e6", "v3f6", "v3f7"],
  },
  {
    name: "v3e6 true ([])",
    appConfig: { charsetsProvidedSync: {}, encodingsProvidedSync: {"chunked":function(body){return body;}} },
    method: "GET",
    path: "/",
    headers: { "Accept-charset": "unicode-1-1", "Accept-encoding": "deflate" },
    checkStatus: 406,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3e6", "v3f6", "v3f7"],
  },
  {
    name: "v3f7 false",
    appConfig: { encodingsProvidedSync: {"chunked":function(body){return body;}, "deflate":function(body){return body;}} },
    method: "GET",
    path: "/",
    headers: { "Accept-encoding": "compress" },
    checkStatus: 406,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3f7"],
  },
  {
    name: "v3f7 true",
    appConfig: { encodingsProvidedSync: {"chunked":function(body){return body;}, "deflate":function(body){return body;}}, resourceExists: false },
    method: "GET",
    path: "/",
    headers: { "Accept-encoding": "deflate", "If-match": "*" },
    checkStatus: 412,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3f7", "v3g7", "v3h7"],
  },
  {
    name: "v3f7 true (*)",
    appConfig: { encodingsProvidedSync: {"chunked":function(body){return body;}, "deflate":function(body){return body;}}, resourceExists: false },
    method: "GET",
    path: "/",
    headers: { "Accept-encoding": "*", "If-match": "*" },
    checkStatus: 412,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3f7", "v3g7", "v3h7"],
  },
  {
    name: "v3f7 true ([])",
    appConfig: { encodingsProvidedSync: {}, resourceExists: false },
    method: "GET",
    path: "/",
    headers: { "Accept-encoding": "deflate", "If-match": "*" },
    checkStatus: 412,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3f7", "v3g7", "v3h7"],
  },
  {
    name: "v3g7 false",
    appConfig: { resourceExists: false },
    method: "GET",
    path: "/",
    headers: { "If-match": "*" },
    checkStatus: 412,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3h7"],
  },
  {
    name: "v3h7 true",
    appConfig: { resourceExists: false },
    method: "GET",
    path: "/",
    headers: { "If-match": "*" },
    checkStatus: 412,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3h7"],
  },
  {
    name: "v3h7 false",
    appConfig: { resourceExists: false, previouslyExisted: false },
    method: "GET",
    path: "/",
    headers: { },
    checkStatus: 404,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3h7", "v3i7", "v3k7", "v3l7"],
  },
  {
    name: "v3i4 true",
    appConfig: { resourceExists: false, allowedMethodsSync: ['PUT'], movedPermanently: "/foo" },
    method: "PUT",
    path: "/",
    headers: { },
    checkStatus: 301,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3h7", "v3i7", "v3i4"],
  },
  {
    name: "v3i4 false",
    appConfig: { resourceExists: false, allowedMethodsSync: ['PUT'], isConflict: true },
    method: "PUT",
    path: "/",
    headers: { },
    checkStatus: 409,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3h7", "v3i7", "v3i4", "v3p3"],
  },
  {
    name: "v3i7 false",
    appConfig: { resourceExists: false, previouslyExisted: false },
    method: "GET",
    path: "/",
    headers: { },
    checkStatus: 404,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3h7", "v3i7", "v3k7", "v3l7"],
  },
  {
    name: "v3i7 true",
    appConfig: { resourceExists: false, allowedMethodsSync: ['PUT'], movedPermanently: "/foo" },
    method: "PUT",
    path: "/",
    headers: { },
    checkStatus: 301,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3h7", "v3i7", "v3i4"],
  },
  {
    name: "v3k5 true",
    appConfig: { resourceExists: false, previouslyExisted: true, movedPermanently: true },
    method: "GET",
    path: "/",
    headers: { },
    checkStatus: 301,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3h7", "v3i7", "v3k7", "v3k5"],
  },
  {
    name: "v3k7 false",
    appConfig: { resourceExists: false, previouslyExisted: true, movedPermanently: false, movedTemporarily: true },
    method: "GET",
    path: "/",
    headers: { },
    checkStatus: 307,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3h7", "v3i7", "v3k7", "v3k5", "v3l5"],
  },
  {
    name: "v3k7 false",
    appConfig: { resourceExists: false, previouslyExisted: false },
    method: "GET",
    path: "/",
    headers: { },
    checkStatus: 404,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3h7", "v3i7", "v3k7", "v3l7"],
  },
  {
    name: "v3k7 true",
    appConfig: { resourceExists: false, previouslyExisted: true, movedPermanently: true },
    method: "GET",
    path: "/",
    headers: { },
    checkStatus: 301,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3h7", "v3i7", "v3k7", "v3k5"],
  },
  {
    name: "v3l5 true",
    appConfig: { resourceExists: false, previouslyExisted: true, movedPermanently: false, movedTemporarily: true },
    method: "GET",
    path: "/",
    headers: { },
    checkStatus: 307,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3h7", "v3i7", "v3k7", "v3k5", "v3l5"],
  },
  {
    name: "v3l5 false",
    appConfig: { resourceExists: false, previouslyExisted: true, movedPermanently: false, movedTemporarily: false },
    method: "GET",
    path: "/",
    headers: { },
    checkStatus: 410,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3h7", "v3i7", "v3k7", "v3k5", "v3l5", "v3m5"],
  },
  {
    name: "v3l7 false",
    appConfig: { resourceExists: false, previouslyExisted: false },
    method: "GET",
    path: "/",
    headers: { },
    checkStatus: 404,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3h7", "v3i7", "v3k7", "v3l7"],
  },
  {
    name: "v3l7 true",
    appConfig: { resourceExists: false, allowedMethodsSync: ["POST"], previouslyExisted: false },
    method: "POST",
    path: "/",
    headers: { },
    checkStatus: 404,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3h7", "v3i7", "v3k7", "v3l7", "v3m7"],
  },
  {
    name: "v3m5 true",
    appConfig: { resourceExists: false, allowedMethodsSync: ["POST"], previouslyExisted: true, movedPermanently: false, movedTemporarily: false },
    method: "POST",
    path: "/",
    headers: { },
    checkStatus: 410,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3h7", "v3i7", "v3k7", "v3k5", "v3l5", "v3m5", "v3n5"],
  },
  {
    name: "v3m5 false",
    appConfig: { resourceExists: false, previouslyExisted: true, movedPermanently: false, movedTemporarily: false },
    method: "GET",
    path: "/",
    headers: { },
    checkStatus: 410,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3h7", "v3i7", "v3k7", "v3k5", "v3l5", "v3m5"],
  },
  {
    name: "v3m7 false",
    appConfig: { resourceExists: false, allowedMethodsSync: ["POST"], previouslyExisted: false },
    method: "POST",
    path: "/",
    headers: { },
    checkStatus: 404,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3h7", "v3i7", "v3k7", "v3l7", "v3m7"],
  },
  {
    name: "v3m7 true",
    appConfig: { resourceExists: false, allowedMethodsSync: ["POST"], previouslyExisted: false, allowMissingPost: true, postIsCreate: true, createPath: "/", contentTypesAcceptedSync: {"application/octet-stream" : function(req, res, next){ res.doRedirect(true); res.setRespHeader("Location", "/foo"); next(true); } } }, //acceptContent: function (context) { context.res.setHeader("Location", "/foo"); return(true) } },
    method: "POST",
    path: "/",
    headers: { },
    checkStatus: 303,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3h7", "v3i7", "v3k7", "v3l7", "v3m7", "v3n11"],
  },
  {
    name: "v3n5 true",
    appConfig: { resourceExists: false, allowedMethodsSync: ["POST"], previouslyExisted: true, movedPermanently: false, movedTemporarily: false, allowMissingPost: true, postIsCreate: true, createPath: "/", contentTypesAcceptedSync: {"application/octet-stream" : function(req, res, next){ res.doRedirect(true); res.setRespHeader("Location", "/foo"); next(true); } } }, // acceptContent: function (context) { context.res.setHeader("Location", "/foo"); return(true) } },
    method: "POST",
    path: "/",
    headers: { },
    checkStatus: 303,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3h7", "v3i7", "v3k7", "v3k5", "v3l5", "v3m5", "v3n5", "v3n11"],
  },
  {
    name: "v3n5 false",
    appConfig: { resourceExists: false, allowedMethodsSync: ["POST"], previouslyExisted: true, movedPermanently: false, movedTemporarily: false },
    method: "POST",
    path: "/",
    headers: { },
    checkStatus: 410,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3h7", "v3i7", "v3k7", "v3k5", "v3l5", "v3m5", "v3n5"],
  },
  {
    name: "v3g7 true",
    appConfig: { resourceExists: true, generateEtag: "yyy" },
    method: "GET",
    path: "/",
    headers: { "If-match": "xxx" },
    checkStatus: 412,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3g9", "v3g11"],
  },
  {
    name: "v3g9 false",
    appConfig: { resourceExists: true, generateEtag: "yyy" },
    method: "GET",
    path: "/",
    headers: { "If-match": "xxx" },
    checkStatus: 412,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3g9", "v3g11"],
  },
  {
    name: "v3g9 true",
    appConfig: { resourceExists: true, lastModified: new Date("2009/11/28 5:23:02 AM") },
    method: "GET",
    path: "/",
    headers: { "If-match": "*", "If-Unmodified-Since": "Fri, 28 Nov 1975 10:23:02 GMT" },
    checkStatus: 412,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3g9", "v3h10", "v3h11", "v3h12"],
  },
  {
    name: "v3g11 false",
    appConfig: { resourceExists: true, generateEtag: "yyy" },
    method: "GET",
    path: "/",
    headers: { "If-match": "xxx" },
    checkStatus: 412,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3g9", "v3g11"],
  },
  {
    name: "v3g11 true",
    appConfig: { resourceExists: true, generateEtag: "xxx", lastModified: new Date("2009/11/28 5:23:02 AM") },
    method: "GET",
    path: "/",
    headers: { "If-match": "xxx", "If-Unmodified-Since": "Fri, 28 Nov 1975 10:23:02 GMT" },
    checkStatus: 412,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3g9", "v3g11", "v3h10", "v3h11", "v3h12"],
  },
  {
    name: "v3h11 false",
    appConfig: { resourceExists: true, allowedMethodsSync: ["POST"] },
    method: "POST",
    path: "/",
    headers: { "If-Unmodified-Since": "kshfkjsdhfkdsjhfs", "If-None-Match": "*" },
    checkStatus: 412,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3h11", "v3i12", "v3i13", "v3j18"],
  },
  {
    name: "v3h12 true",
    appConfig: { resourceExists: true, generateEtag: "xxx", lastModified: new Date("2009/11/28 5:23:02 AM") },
    method: "GET",
    path: "/",
    headers: { "If-match": "xxx", "If-Unmodified-Since": "Fri, 28 Nov 1975 10:23:02 GMT" },
    checkStatus: 412,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3g9", "v3g11", "v3h10", "v3h11", "v3h12"],
  },
  {
    name: "v3h12 false",
    appConfig: { lastModified: new Date("1975/11/28 5:23:02 AM") },
    method: "GET",
    path: "/",
    headers: { "If-Unmodified-Since": "Sat, 28 Nov 2009 10:23:02 GMT", "If-None-Match": "*" },
    checkStatus: 304,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3h11", "v3h12", "v3i12", "v3i13", "v3j18"],
  },
  {
    name: "v3i13 true",
    appConfig: { canHandleResource: true },
    method: "GET",
    path: "/",
    headers: { "If-None-Match": "*" },
    checkStatus: 304,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3i13", "v3j18"],
  },
  {
    name: "v3i13 false",
    appConfig: { generateEtag: "xxx" },
    method: "GET",
    path: "/",
    headers: { "If-None-Match": "xxx" },
    checkStatus: 304,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3i13", "v3k13", "v3j18"],
  },
  {
    name: "v3k13 true",
    appConfig: { generateEtag: "xxx" },
    method: "GET",
    path: "/",
    headers: { "If-None-Match": "xxx" },
    checkStatus: 304,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3i13", "v3k13", "v3j18"],
  },
  {
    name: "v3j18 false",
    appConfig: { allowedMethodsSync: ["POST"] },
    method: "POST",
    path: "/",
    headers: { "If-None-Match": "*" },
    checkStatus: 412,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3i13", "v3j18"],
  },
  {
    name: "v3j18 true (GET)",
    appConfig: { canHandleResource: true },
    method: "GET",
    path: "/",
    headers: { "If-None-Match": "*" },
    checkStatus: 304,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3i13", "v3j18"],
  },
  {
    name: "v3j18 true (HEAD)",
    appConfig: { canHandleResource: true },
    method: "HEAD",
    path: "/",
    headers: { "If-None-Match": "*" },
    checkStatus: 304,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3i13", "v3j18"],
  },
  {
    name: "v3k13 false",
    appConfig: { generateEtag: "yyy", lastModified: new Date("1975/11/28 5:23:02 AM") },
    method: "GET",
    path: "/",
    headers: { "If-None-Match": "xxx", "If-Modified-Since": "Sat, 28 Nov 2009 10:23:02 GMT" },
    checkStatus: 304,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3i13", "v3k13", "v3l13", "v3l14", "v3l15", "v3l17"],
  },
  {
    name: "v3l14 false",
    appConfig: { allowedMethodsSync: ['DELETE'], deleteResource: true, deleteCompleted: false },
    method: "DELETE",
    path: "/",
    headers: { "If-Modified-Since": "smdgfshdgfhjsgdfjsnfd" },
    checkStatus: 202,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3l13", "v3l14", "v3m16", "v3m20", "v3m20b"],
  },
  {
    name: "v3l15 true",
    appConfig: { allowedMethodsSync: ['DELETE'], deleteResource: true, deleteCompleted: false },
    method: "DELETE",
    path: "/",
    headers: { "If-Modified-Since": "Wed, 28 Nov 2029 10:23:02 GMT" },
    checkStatus: 202,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3l13", "v3l14", "v3l15", "v3m16", "v3m20", "v3m20b"],
  },
  {
    name: "v3l17 true",
    appConfig: { lastModified: new Date("2009/11/28 5:23:02 AM"), allowedMethodsSync: ['DELETE'], deleteResource: true, deleteCompleted: false },
    method: "DELETE",
    path: "/",
    headers: { "If-Modified-Since": "Fri, 28 Nov 1975 10:23:02 GMT" },
    checkStatus: 202,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3l13", "v3l14", "v3l15", "v3l17", "v3m16", "v3m20", "v3m20b"],
  },
  {
    name: "v3l17 false",
    appConfig: { lastModified: new Date("1975/11/28 5:23:02 AM") },
    method: "GET",
    path: "/",
    headers: { "If-Modified-Since": "Sat, 28 Nov 2009 10:23:02 GMT" },
    checkStatus: 304,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3l13", "v3l14", "v3l15", "v3l17"],
  },
  {
    name: "v3m16 true",
    appConfig: { allowedMethodsSync: ['DELETE'], deleteResource: true, deleteCompleted: false },
    method: "DELETE",
    path: "/",
    headers: { },
    checkStatus: 202,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3l13", "v3m16", "v3m20", "v3m20b"],
  },
  {
    name: "v3m16 false",
    appConfig: { deleteResource: true, deleteCompleted: false },
    method: "GET",
    path: "/",
    headers: { },
    checkStatus: 200,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3l13", "v3m16", "v3n16", "v3o16", "v3o18", "v3o18b"],
  },
  {
    name: "v3n16 false",
    appConfig: { deleteResource: true, deleteCompleted: false },
    method: "GET",
    path: "/",
    headers: { },
    checkStatus: 200,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3l13", "v3m16", "v3n16", "v3o16", "v3o18", "v3o18b"],
  },
  {
    name: "v3n16 true",
    appConfig: { deleteResource: true, deleteCompleted: false, allowedMethodsSync: ['POST'], postIsCreate: true, createPath: "/", contentTypesAcceptedSync: {"application/octet-stream" : function(req, res, next){ res.doRedirect(true); res.setRespHeader("Location", "/foo"); next(true); } } }, //acceptContent: function (context) { context.res.setHeader("Location", "/foo"); return(true) } },
    method: "POST",
    path: "/",
    headers: { },
    checkStatus: 303,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3l13", "v3m16", "v3n16", "v3n11"],
  },
  {
    name: "v3n11 true (redirect)",
    appConfig: { deleteResource: true, deleteCompleted: false, allowedMethodsSync: ['POST'], postIsCreate: true, createPath: "/", contentTypesAcceptedSync: {"application/octet-stream" : function(req, res, next){ res.doRedirect(true); res.setRespHeader("Location", "/foo"); next(true); } } }, //acceptContent: function (context) { context.res.setHeader("Location", "/foo"); return(true) } },
    method: "POST",
    path: "/",
    headers: { },
    checkStatus: 303,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3l13", "v3m16", "v3n16", "v3n11"],
  },
  {
    name: "v3n11 true (no redirect)",
    appConfig: { deleteResource: true, deleteCompleted: false, allowedMethodsSync: ['POST'], postIsCreate: true, createPath: "/", contentTypesAcceptedSync: {"application/octet-stream" : function(req, res, next){ res.doRedirect(false); res.setRespHeader("Location", "/foo"); next(true); } } }, //acceptContent: function (context) { context.res.setHeader("Location", "/foo"); return(true) } },
    method: "POST",
    path: "/",
    headers: { },
    checkStatus: 201,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3l13", "v3m16", "v3n16", "v3n11", "v3p11"],
  },  
  {
    name: "v3n11 false",
    appConfig: { deleteResource: true, deleteCompleted: false, allowedMethodsSync: ['POST'], postIsCreate: false, processPost: function(req, res, next) { res.setRespHeader("Location", "/foo"); next(true); } },
    method: "POST",
    path: "/",
    headers: { },
    checkStatus: 201,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3l13", "v3m16", "v3n16", "v3n11", "v3p11"],
  },
  {
    name: "v3p3 true",
    appConfig: { resourceExists: false, allowedMethodsSync: ['PUT'], isConflict: true },
    method: "PUT",
    path: "/",
    headers: { },
    checkStatus: 409,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3h7", "v3i7", "v3i4", "v3p3"],
  },
  {
    name: "v3p3 false",
    appConfig: { resourceExists: false, allowedMethodsSync: ['PUT'], isConflict: false, contentTypesAcceptedSync: {"application/octet-stream" : function(req, res, next){ res.doRedirect(true); res.setRespHeader("Location", "/foo"); next(true); } } }, //acceptContent: function (context) { context.res.setHeader("Location", "/foo"); return(true) } },
    method: "PUT",
    path: "/",
    headers: { },
    checkStatus: 201,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3h7", "v3i7", "v3i4", "v3p3", "v3p11"],
  },
  {
    name: "v3p11 true",
    appConfig: { deleteResource: true, deleteCompleted: false, allowedMethodsSync: ['POST'], postIsCreate: false, processPost: function(req, res, next) { res.setRespHeader("Location", "/foo"); next(true); } },
    method: "POST",
    path: "/",
    headers: { },
    checkStatus: 201,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3l13", "v3m16", "v3n16", "v3n11", "v3p11"],
  },
  {
    name: "v3p11 false",
    appConfig: { deleteResource: true, deleteCompleted: false, allowedMethodsSync: ['POST'], postIsCreate: false, processPost: true },
    method: "POST",
    path: "/",
    headers: { },
    checkStatus: 204,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3l13", "v3m16", "v3n16", "v3n11", "v3p11", "v3o20"],
  },
  {
    name: "v3o16 false",
    appConfig: { deleteResource: true, deleteCompleted: false },
    method: "GET",
    path: "/",
    headers: { },
    checkStatus: 200,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3l13", "v3m16", "v3n16", "v3o16", "v3o18", "v3o18b"],
  },
  {
    name: "v3o16 true",
    appConfig: { deleteResource: true, deleteCompleted: false, allowedMethodsSync: ['PUT'], isConflict: true },
    method: "PUT",
    path: "/",
    headers: { },
    checkStatus: 409,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3l13", "v3m16", "v3n16", "v3o16", "v3o14"],
  },
  {
    name: "v3o14 true",
    appConfig: { deleteResource: true, deleteCompleted: false, allowedMethodsSync: ['PUT'], isConflict: true },
    method: "PUT",
    path: "/",
    headers: { },
    checkStatus: 409,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3l13", "v3m16", "v3n16", "v3o16", "v3o14"],
  },
  {
    name: "v3o14 false",
    appConfig: { deleteResource: true, deleteCompleted: false, allowedMethodsSync: ['PUT'], isConflict: false, contentTypesAcceptedSync: {"application/octet-stream" : function(req, res, next){ res.setRespHeader("Location", "/foo"); next(true); } } }, //acceptContent: function (context) { context.res.setHeader("Location", "/foo"); return(true) } },
    method: "PUT",
    path: "/",
    headers: { },
    checkStatus: 201,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3l13", "v3m16", "v3n16", "v3o16", "v3o14", "v3p11"],
  },
  {
    name: "v3o18 false",
    appConfig: { deleteResource: true, deleteCompleted: false },
    method: "GET",
    path: "/",
    headers: { },
    checkStatus: 200,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3l13", "v3m16", "v3n16", "v3o16", "v3o18", "v3o18b"],
  },
  {
    name: "v3o18 true",
    appConfig: { deleteResource: true, deleteCompleted: false, multipleChoices: true },
    method: "GET",
    path: "/",
    headers: { },
    checkStatus: 300,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3l13", "v3m16", "v3n16", "v3o16", "v3o18", "v3o18b"],
  },
  {
    name: "v3m20 false",
    appConfig: { allowedMethodsSync: ['DELETE'], deleteResource: true, deleteCompleted: false },
    method: "DELETE",
    path: "/",
    headers: { },
    checkStatus: 202,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3l13", "v3m16", "v3m20", "v3m20b"],
  },
  {
    name: "v3o20 false",
    appConfig: { allowedMethodsSync: ['DELETE'], deleteResource: true, deleteCompleted: true }, //responseEntityExists: false },
    method: "DELETE",
    path: "/",
    headers: { },
    checkStatus: 204,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3l13", "v3m16", "v3m20", "v3m20b", "v3o20"],
  },
  // TODO: Rewrite with responseEntityExists replacement
  // {
  //   name: "v3o20 true",
  //   appConfig: { allowedMethodsSync: ['DELETE'], deleteResource: true, deleteCompleted: true, responseEntityExists: true },
  //   method: "DELETE",
  //   path: "/",
  //   headers: { },
  //   checkStatus: 200,
  //   checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3l13", "v3m16", "v3m20", "v3m20b", "v3o20", "v3o18"],
  // },
  {
    name: "Send ETag",
    appConfig: { generateEtag: "xxx" },
    method: "GET",
    path: "/",
    headers: { },
    checkStatus: 200,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3l13", "v3m16", "v3n16", "v3o16", "v3o18", "v3o18b"],
    checkHeaders: function (headers) {
      return(headers["etag"] == "xxx");
    }
  },
  {
    name: "Send Expires",
    appConfig: { resourceExpiration: new Date("Fri, 28 Nov 1975 10:23:02 GMT") },
    method: "GET",
    path: "/",
    headers: { },
    checkStatus: 200,
    checkStack: ["v3b13", "v3b13b", "v3b12", "v3b11", "v3b10", "v3b9", "v3b8", "v3b7", "v3b6", "v3b5", "v3b4", "v3b3", "v3c3", "v3d4", "v3e5", "v3f6", "v3g7", "v3g8", "v3h10", "v3i12", "v3l13", "v3m16", "v3n16", "v3o16", "v3o18", "v3o18b"],
    checkHeaders: function (headers) {
      return(headers["expires"] == "Fri, 28 Nov 1975 10:23:02 GMT");
    }
  },
];
